pub trait Decodable<'tx> {
// Required method
fn decode(data_val: &[u8]) -> Result<Self, Error>
where Self: Sized;
}Expand description
Implement this to be able to decode data values
pub trait Decodable<'tx> {
// Required method
fn decode(data_val: &[u8]) -> Result<Self, Error>
where Self: Sized;
}Implement this to be able to decode data values